# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added/New

### Fixed/Removed

### Internal

## [0.0.1] - 2025-11-14

Today, we are releasing a cleaned up version of the library used in the experiments for our NeurIPS 2025 paper.
The repository also hosts the LaTeX source for the paper and poster.

[Unreleased]: https://github.com/f-dangel/torch-jet/compare/0.0.1...HEAD
[0.0.1]: https://github.com/f-dangel/torch-jet/releases/tag/0.0.1
